@@ -201,7 +201,7 @@ class Microservices(BaseClass, ABC):
                     'reporting_host': os.environ.get('JAEGER_AGENT_HOST', 'jaeger-agent.logging'),
                     'reporting_port': os.environ.get('JAEGER_AGENT_PORT', 6831),
                 },
-                'logging': True if os.environ.get('PRODUCTION', False) else False,
+                'logging': False if os.environ.get('PRODUCTION', None) is None else True,
                 'tags': {
                     '@coppel-py-version': version
                 }
